@@ -120,7 +120,7 @@ ChangePassphraseCommand::ChangePassphraseCommand(QAbstractItemView *v, KeyListCo
 }
 
 ChangePassphraseCommand::ChangePassphraseCommand(const GpgME::Key &key)
-    : Command(key, new Private(this, 0))
+    : Command(key, new Private(this, nullptr))
 {
     d->init();
 }
