@@ -3,6 +3,8 @@
 
     This file is part of Kleopatra, the KDE keymanager
     Copyright (c) 2008 Klarälvdalens Datakonsult AB
+    2016 by Bundesamt für Sicherheit in der Informationstechnik
+    Software engineering by Intevation GmbH
 
     Kleopatra is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,10 +38,15 @@
 
 #include "utils/auditlog.h"
 #include "commands/command.h"
+#include "commands/importcertificatefromfilecommand.h"
+#include "commands/lookupcertificatescommand.h"
+#include "crypto/decryptverifytask.h"
 
 #include <libkleo/messagebox.h>
 #include <Libkleo/Classify>
 
+#include <gpgme++/key.h>
+
 #include <KLocalizedString>
 #include <QPushButton>
 #include <KStandardGuiItem>
@@ -68,7 +75,7 @@ static QColor colorForVisualCode(Task::Result::VisualCode code)
         return KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::PositiveBackground).color();
     case Task::Result::NeutralError:
     case Task::Result::Warning:
-        return KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::NeutralBackground).color();
+        return KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::NormalBackground).color();
     case Task::Result::Danger:
         return KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::NegativeBackground).color();
     case Task::Result::NeutralSuccess:
@@ -83,7 +90,7 @@ static QColor txtColorForVisualCode(Task::Result::VisualCode code)
         return KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::PositiveText).color();
     case Task::Result::NeutralError:
     case Task::Result::Warning:
-        return KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::NeutralText).color();
+        return KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::NormalText).color();
     case Task::Result::Danger:
         return KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::NegativeText).color();
     case Task::Result::NeutralSuccess:
@@ -97,7 +104,7 @@ class ResultItemWidget::Private
 {
     ResultItemWidget *const q;
 public:
-    explicit Private(const std::shared_ptr<const Task::Result> &result, ResultItemWidget *qq) : q(qq), m_result(result), m_detailsLabel(nullptr), m_showDetailsLabel(nullptr), m_closeButton(nullptr)
+    explicit Private(const std::shared_ptr<const Task::Result> &result, ResultItemWidget *qq) : q(qq), m_result(result), m_detailsLabel(nullptr), m_actionsLabel(nullptr), m_closeButton(nullptr), m_importCanceled(false)
     {
         assert(m_result);
     }
@@ -105,12 +112,98 @@ public:
     void slotLinkActivated(const QString &);
     void updateShowDetailsLabel();
 
+    void addKeyImportButton(QBoxLayout *lay, bool search);
+
+    void oneImportFinished();
+
     const std::shared_ptr<const Task::Result> m_result;
     QLabel *m_detailsLabel;
-    QLabel *m_showDetailsLabel;
+    QLabel *m_actionsLabel;
     QPushButton *m_closeButton;
+    bool m_importCanceled;
 };
 
+void ResultItemWidget::Private::oneImportFinished()
+{
+    if (m_importCanceled) {
+        return;
+    }
+    if (m_result->parentTask()) {
+        m_result->parentTask()->start();
+    }
+    q->setVisible(false);
+}
+
+void ResultItemWidget::Private::addKeyImportButton(QBoxLayout *lay, bool search)
+{
+    if (!m_result || !lay) {
+        return;
+    }
+
+    const auto dvResult = dynamic_cast<const DecryptVerifyResult *>(m_result.get());
+    if (!dvResult) {
+        return;
+    }
+    const auto verifyResult = dvResult->verificationResult();
+
+    if (verifyResult.isNull()) {
+        return;
+    }
+
+    for (const auto sig: verifyResult.signatures()) {
+        if (!(sig.summary() & GpgME::Signature::KeyMissing)) {
+            continue;
+        }
+
+        auto btn = new QPushButton;
+        QString suffix;
+        const auto keyid = QLatin1String(sig.fingerprint());
+        if (verifyResult.numSignatures() > 1) {
+            suffix = QLatin1Char(' ') + keyid;
+        }
+        btn = new QPushButton(search ? i18nc("1 is optional keyid. No space is intended as it can be empty.",
+                                       "Search%1", suffix)
+                                     : i18nc("1 is optional keyid. No space is intended as it can be empty.",
+                                       "Import%1", suffix));
+
+        if (search) {
+            btn->setIcon(QIcon::fromTheme("edit-find"));
+            connect (btn, &QPushButton::clicked, q, [this, btn, keyid] () {
+                btn->setEnabled(false);
+                m_importCanceled = false;
+                auto cmd = new Kleo::Commands::LookupCertificatesCommand(keyid, nullptr);
+                connect(cmd, &Kleo::Commands::LookupCertificatesCommand::canceled,
+                        q, [this]() { m_importCanceled = true; });
+                connect(cmd, &Kleo::Commands::LookupCertificatesCommand::finished,
+                        q, [this, btn]() {
+                    btn->setEnabled(true);
+                    oneImportFinished();
+                });
+                cmd->setParentWidget(q);
+                cmd->start();
+            });
+        } else {
+            btn->setIcon(QIcon::fromTheme("view-certificate-import"));
+            connect (btn, &QPushButton::clicked, q, [this, btn] () {
+                btn->setEnabled(false);
+                m_importCanceled = false;
+                auto cmd = new Kleo::ImportCertificateFromFileCommand();
+                connect(cmd, &Kleo::ImportCertificateFromFileCommand::canceled,
+                        q, [this]() { m_importCanceled = true; });
+                connect(cmd, &Kleo::ImportCertificateFromFileCommand::finished,
+                        q, [this, btn]() {
+                    btn->setEnabled(true);
+                    oneImportFinished();
+                });
+                cmd->setParentWidget(q);
+                cmd->start();
+            });
+        }
+        btn->setFixedSize(btn->sizeHint());
+        lay->addWidget(btn);
+    }
+}
+
 static QUrl auditlog_url_template()
 {
     QUrl url(QStringLiteral("kleoresultitem://showauditlog"));
@@ -119,37 +212,28 @@ static QUrl auditlog_url_template()
 
 void ResultItemWidget::Private::updateShowDetailsLabel()
 {
-    if (!m_showDetailsLabel || !m_detailsLabel) {
+    if (!m_actionsLabel || !m_detailsLabel) {
         return;
     }
 
-    const bool detailsVisible = m_detailsLabel->isVisible();
     const QString auditLogLink = m_result->auditLog().formatLink(auditlog_url_template());
-    m_showDetailsLabel->setText(QStringLiteral("<a href=\"kleoresultitem://toggledetails/\">%1</a><br/>%2").arg(detailsVisible ? i18n("Hide Details") : i18n("Show Details"), auditLogLink));
-    m_showDetailsLabel->setAccessibleDescription(detailsVisible ? i18n("Hide Details") : i18n("Show Details"));
+    m_actionsLabel->setText(auditLogLink);
 }
 
 ResultItemWidget::ResultItemWidget(const std::shared_ptr<const Task::Result> &result, QWidget *parent, Qt::WindowFlags flags) : QWidget(parent, flags), d(new Private(result, this))
 {
     const QColor color = colorForVisualCode(d->m_result->code());
     const QColor txtColor = txtColorForVisualCode(d->m_result->code());
-    const QString styleSheet = QStringLiteral("* { background-color: %1; margin: 0px; }"
+    const QString styleSheet = QStringLiteral("QFrame,QLabel { background-color: %1; margin: 0px; }"
                                               "QFrame#resultFrame{ border-color: %2; border-style: solid; border-radius: 3px; border-width: 1px }"
                                               "QLabel { color: %3; padding: 5px; border-radius: 3px }").arg(color.name()).arg(color.darker(150).name()).arg(txtColor.name());
     QVBoxLayout *topLayout = new QVBoxLayout(this);
-    topLayout->setMargin(0);
-    topLayout->setSpacing(0);
     QFrame *frame = new QFrame;
     frame->setObjectName(QStringLiteral("resultFrame"));
     frame->setStyleSheet(styleSheet);
     topLayout->addWidget(frame);
-    QVBoxLayout *layout = new QVBoxLayout(frame);
-    layout->setMargin(0);
-    layout->setSpacing(0);
-    QWidget *hbox = new QWidget;
-    QHBoxLayout *hlay = new QHBoxLayout(hbox);
-    hlay->setMargin(0);
-    hlay->setSpacing(0);
+    QHBoxLayout *layout = new QHBoxLayout(frame);
+    QVBoxLayout *vlay = new QVBoxLayout();
     QLabel *overview = new QLabel;
     overview->setWordWrap(true);
     overview->setTextFormat(Qt::RichText);
@@ -158,18 +242,24 @@ ResultItemWidget::ResultItemWidget(const std::shared_ptr<const Task::Result> &re
     overview->setStyleSheet(styleSheet);
     connect(overview, SIGNAL(linkActivated(QString)), this, SLOT(slotLinkActivated(QString)));
 
-    hlay->addWidget(overview, 1, Qt::AlignTop);
-    layout->addWidget(hbox);
+    vlay->addWidget(overview);
+    layout->addLayout(vlay);
 
     const QString details = d->m_result->details();
 
-    d->m_showDetailsLabel = new QLabel;
-    connect(d->m_showDetailsLabel, SIGNAL(linkActivated(QString)), this, SLOT(slotLinkActivated(QString)));
-    hlay->addWidget(d->m_showDetailsLabel);
-    d->m_showDetailsLabel->setVisible(!details.isEmpty());
-    d->m_showDetailsLabel->setFocusPolicy(Qt::StrongFocus);
-    d->m_showDetailsLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
-    d->m_showDetailsLabel->setStyleSheet(styleSheet);
+    QVBoxLayout *actionLayout = new QVBoxLayout;
+    layout->addLayout(actionLayout);
+
+    d->addKeyImportButton(actionLayout, false);
+    // TODO: Only show if auto-key-retrieve is not set.
+    d->addKeyImportButton(actionLayout, true);
+
+    d->m_actionsLabel = new QLabel;
+    connect(d->m_actionsLabel, SIGNAL(linkActivated(QString)), this, SLOT(slotLinkActivated(QString)));
+    actionLayout->addWidget(d->m_actionsLabel);
+    d->m_actionsLabel->setFocusPolicy(Qt::StrongFocus);
+    d->m_actionsLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
+    d->m_actionsLabel->setStyleSheet(styleSheet);
 
     d->m_detailsLabel = new QLabel;
     d->m_detailsLabel->setWordWrap(true);
@@ -178,19 +268,23 @@ ResultItemWidget::ResultItemWidget(const std::shared_ptr<const Task::Result> &re
     d->m_detailsLabel->setFocusPolicy(Qt::StrongFocus);
     d->m_detailsLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
     d->m_detailsLabel->setStyleSheet(styleSheet);
-    connect(d->m_detailsLabel, SIGNAL(linkActivated(QString)), this, SLOT(slotLinkActivated(QString)));
-    layout->addWidget(d->m_detailsLabel);
 
-    d->m_detailsLabel->setVisible(false);
+    connect(d->m_detailsLabel, SIGNAL(linkActivated(QString)), this, SLOT(slotLinkActivated(QString)));
+    vlay->addWidget(d->m_detailsLabel);
 
     d->m_closeButton = new QPushButton;
     KGuiItem::assign(d->m_closeButton, KStandardGuiItem::close());
     d->m_closeButton->setFixedSize(d->m_closeButton->sizeHint());
     connect(d->m_closeButton, &QAbstractButton::clicked, this, &ResultItemWidget::closeButtonClicked);
-    layout->addWidget(d->m_closeButton, 0, Qt::AlignRight);
+    actionLayout->addWidget(d->m_closeButton);
     d->m_closeButton->setVisible(false);
 
+    layout->setStretch(0, 1);
+    actionLayout->addStretch(-1);
+    vlay->addStretch(-1);
+
     d->updateShowDetailsLabel();
+    setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum);
 }
 
 ResultItemWidget::~ResultItemWidget()
@@ -202,11 +296,6 @@ void ResultItemWidget::showCloseButton(bool show)
     d->m_closeButton->setVisible(show);
 }
 
-bool ResultItemWidget::detailsVisible() const
-{
-    return d->m_detailsLabel && d->m_detailsLabel->isVisible();
-}
-
 bool ResultItemWidget::hasErrorResult() const
 {
     return d->m_result->hasError();
@@ -233,10 +322,6 @@ void ResultItemWidget::Private::slotLinkActivated(const QString &link)
     }
 
     const QUrl url(link);
-    if (url.host() == QLatin1String("toggledetails")) {
-        q->showDetails(!q->detailsVisible());
-        return;
-    }
 
     if (url.host() == QLatin1String("showauditlog")) {
         q->showAuditLog();
@@ -250,14 +335,4 @@ void ResultItemWidget::showAuditLog()
     MessageBox::auditLog(parentWidget(), d->m_result->auditLog().text());
 }
 
-void ResultItemWidget::showDetails(bool show)
-{
-    if (show == d->m_detailsLabel->isVisible()) {
-        return;
-    }
-    d->m_detailsLabel->setVisible(show);
-    d->updateShowDetailsLabel();
-    Q_EMIT detailsToggled(show);
-}
-
 #include "moc_resultitemwidget.cpp"
