@@ -81,7 +81,7 @@ public:
 
     }
 
-    QVariant data(const QModelIndex &mi, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE
+    QVariant data(const QModelIndex &mi, int role = Qt::DisplayRole) const override
     {
         if (mi.isValid() && role == Qt::BackgroundRole) {
             const QHash<QString, VerifyChecksumsDialog::Status>::const_iterator
