@@ -3,7 +3,8 @@
 /*  smartcard/card.h
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2017 Intevation GmbH
+    Copyright (c) 2017 by Bundesamt für Sicherheit in der Informationstechnik
+    Software engineering by Intevation GmbH
 
     Kleopatra is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -78,7 +79,7 @@ public:
     };
 
     Card();
-    virtual ~Card() {};
+    virtual ~Card() {}
 
     virtual bool operator == (const Card& other) const;
     bool operator != (const Card& other) const;
