@@ -64,7 +64,7 @@ class TreeView : public QTreeView
 public:
     explicit TreeView(QWidget *parent = nullptr) : QTreeView(parent) {}
 
-    QSize minimumSizeHint() const Q_DECL_OVERRIDE
+    QSize minimumSizeHint() const override
     {
         const QSize min = QTreeView::minimumSizeHint();
         return QSize(min.width(), min.height() + 5 * fontMetrics().height());
@@ -207,6 +207,7 @@ void KeyTreeView::init()
     /* TODO: Make this configurable by the user. E.g. kdepim/src/todo/todoview.cpp */
     rearangingModel->setSourceColumns(QVector<int>() << KeyListModelInterface::PrettyName
                                                      << KeyListModelInterface::PrettyEMail
+                                                     << KeyListModelInterface::Validity
                                                      << KeyListModelInterface::ValidFrom
                                                      << KeyListModelInterface::ValidUntil
                                                      << KeyListModelInterface::TechnicalDetails
@@ -216,6 +217,7 @@ void KeyTreeView::init()
     std::vector<int> defaultSizes;
     defaultSizes.push_back(280);
     defaultSizes.push_back(280);
+    defaultSizes.push_back(120);
     defaultSizes.push_back(100);
     defaultSizes.push_back(100);
     defaultSizes.push_back(80);
