@@ -1,7 +1,8 @@
 /*  view/pgpcardwiget.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2017 Intevation GmbH
+    Copyright (c) 2017 by Bundesamt für Sicherheit in der Informationstechnik
+    Software engineering by Intevation GmbH
 
     Kleopatra is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -96,7 +97,7 @@ class GenKeyThread: public QThread
             return mBkpFile;
         }
     protected:
-        void run() Q_DECL_OVERRIDE {
+        void run() override {
             GpgME::GpgGenCardKeyInteractor *ei = new GpgME::GpgGenCardKeyInteractor(mSerial);
             ei->setKeySize(mParams.keysize);
             ei->setNameUtf8(mParams.name.toStdString());
