@@ -59,7 +59,7 @@ class TabWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit TabWidget(QWidget *parent = Q_NULLPTR, Qt::WindowFlags f = 0);
+    explicit TabWidget(QWidget *parent = nullptr, Qt::WindowFlags f = 0);
     ~TabWidget();
 
     void setFlatModel(AbstractKeyListModel *model);
@@ -69,7 +69,7 @@ public:
 
     QAbstractItemView *addView(const QString &title = QString(), const QString &keyFilterID = QString(), const QString &searchString = QString());
     QAbstractItemView *addView(const KConfigGroup &group);
-    QAbstractItemView *addTemporaryView(const QString &title = QString(), AbstractKeyListSortFilterProxyModel *proxy = 0, const QString &tabToolTip = QString());
+    QAbstractItemView *addTemporaryView(const QString &title = QString(), AbstractKeyListSortFilterProxyModel *proxy = nullptr, const QString &tabToolTip = QString());
 
     void loadViews(const KConfig *cfg);
     void saveViews(KConfig *cfg) const;
